/* Generated by Cython 0.18 on Mon Dec  9 16:00:33 2013 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_AsInt(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#if PY_MAJOR_VERSION < 3 && PY_MINOR_VERSION < 6
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((k=k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__h5py__h5ac
#define __PYX_HAVE_API__h5py__h5ac
#include "stdlib.h"
#include "string.h"
#include "time.h"
#include "unistd.h"
#include "stdint.h"
#include "api_compat.h"
#include "lzf_filter.h"
#include "hdf5.h"
#include "H5Cpublic.h"
#include "hdf5_hl.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const long n; const char* encoding; const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/

#define __Pyx_PyBytes_FromUString(s) PyBytes_FromString((char*)s)
#define __Pyx_PyBytes_AsUString(s)   ((unsigned char*) PyBytes_AsString(s))
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject*);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))


#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
    
static PyObject *__pyx_m;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "h5ac.pyx",
  "_objects.pxd",
};

/*--- Type declarations ---*/
struct __pyx_obj_4h5py_4h5ac_CacheConfig;
struct __pyx_obj_4h5py_8_objects_ObjectID;

/* "h5py/h5ac.pxd":12
 * from defs cimport *
 * 
 * cdef class CacheConfig:             # <<<<<<<<<<<<<<
 *     cdef H5AC_cache_config_t cache_config
 */
struct __pyx_obj_4h5py_4h5ac_CacheConfig {
  PyObject_HEAD
  H5AC_cache_config_t cache_config;
};

struct __pyx_obj_4h5py_8_objects_ObjectID {
  PyObject_HEAD
  PyObject *__weakref__;
  hid_t id;
  int locked;
  PyObject *_hash;
};

#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed); /*proto*/

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseImportError(PyObject *name);

static CYTHON_INLINE hbool_t __Pyx_PyInt_from_py_hbool_t(PyObject *);

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_hbool_t(hbool_t);

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_hid_t(hid_t);

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject *);

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject *);

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject *);

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject *);

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject *);

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject *);

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject *);

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject *);

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject *);

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject *);

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject *);

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject *);

static int __Pyx_check_binary_version(void);

#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

static PyObject *__Pyx_ImportModule(const char *name); /*proto*/

static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);  /*proto*/

static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig); /*proto*/

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'h5py.api_types_ext' */

/* Module declarations from 'h5py.api_types_hdf5' */

/* Module declarations from 'h5py.defs' */

/* Module declarations from 'h5py._objects' */
static PyTypeObject *__pyx_ptype_4h5py_8_objects_ObjectID = 0;
static hid_t (*__pyx_f_4h5py_8_objects_pdefault)(struct __pyx_obj_4h5py_8_objects_ObjectID *); /*proto*/

/* Module declarations from 'h5py.h5ac' */
static PyTypeObject *__pyx_ptype_4h5py_4h5ac_CacheConfig = 0;
#define __Pyx_MODULE_NAME "h5py.h5ac"
int __pyx_module_is_main_h5py__h5ac = 0;

/* Implementation of 'h5py.h5ac' */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig___cinit__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_7version___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_7version_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, int __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_17evictions_enabled___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_17evictions_enabled_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_16set_initial_size___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_16set_initial_size_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_12initial_size___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_12initial_size_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_18min_clean_fraction___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_18min_clean_fraction_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_8max_size___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_8max_size_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_8min_size___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_8min_size_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_12epoch_length___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_12epoch_length_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, long __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_9incr_mode___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_9incr_mode_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, enum H5C_cache_incr_mode __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_9increment___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_9increment_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_increment___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_increment_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_13max_increment___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_13max_increment_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_incr_mode___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_incr_mode_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, enum H5C_cache_flash_incr_mode __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_14flash_multiple___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_14flash_multiple_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_threshold___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_threshold_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_9decr_mode___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_9decr_mode_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, enum H5C_cache_decr_mode __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_9decrement___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_9decrement_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_decrement___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_decrement_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_13max_decrement___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_13max_decrement_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, int __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_13empty_reserve___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_13empty_reserve_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val); /* proto */
static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self); /* proto */
static int __pyx_pf_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, int __pyx_v_val); /* proto */
static char __pyx_k_1[] = "\n    Low-level HDF5 \"H5AC\" cache configuration interface.\n";
static char __pyx_k__h5py[] = "h5py";
static char __pyx_k____main__[] = "__main__";
static char __pyx_k____test__[] = "__test__";
static char __pyx_k___objects[] = "_objects";
static PyObject *__pyx_n_s____main__;
static PyObject *__pyx_n_s____test__;
static PyObject *__pyx_n_s___objects;
static PyObject *__pyx_n_s__h5py;

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig___cinit__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":24
 *     #cdef H5AC_cache_config_t cache_config
 *     #     /[inserted by cython to avoid comment start]* general configuration fields: *[inserted by cython to avoid comment closer]/
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.cache_config.version = H5AC__CURR_CACHE_CONFIG_VERSION
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig___cinit__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "h5py/h5ac.pyx":25
 *     #     /[inserted by cython to avoid comment start]* general configuration fields: *[inserted by cython to avoid comment closer]/
 *     def __cinit__(self):
 *         self.cache_config.version = H5AC__CURR_CACHE_CONFIG_VERSION             # <<<<<<<<<<<<<<
 * 
 *     property version:
 */
  __pyx_v_self->cache_config.version = H5AC__CURR_CACHE_CONFIG_VERSION;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_7version_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_7version_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_7version___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":28
 * 
 *     property version:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.version
 *         def __set__(self, int val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_7version___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":29
 *     property version:
 *         def __get__(self):
 *             return self.cache_config.version             # <<<<<<<<<<<<<<
 *         def __set__(self, int val):
 *             self.cache_config.version = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->cache_config.version); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 29; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.version.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_7version_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_7version_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  int __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_AsInt(__pyx_arg_val); if (unlikely((__pyx_v_val == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.version.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_7version_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((int)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":30
 *         def __get__(self):
 *             return self.cache_config.version
 *         def __set__(self, int val):             # <<<<<<<<<<<<<<
 *             self.cache_config.version = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_7version_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, int __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":31
 *             return self.cache_config.version
 *         def __set__(self, int val):
 *             self.cache_config.version = val             # <<<<<<<<<<<<<<
 * 
 *     property rpt_fcn_enabled:
 */
  __pyx_v_self->cache_config.version = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":34
 * 
 *     property rpt_fcn_enabled:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.rpt_fcn_enabled
 *         def __set__(self, hbool_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":35
 *     property rpt_fcn_enabled:
 *         def __get__(self):
 *             return self.cache_config.rpt_fcn_enabled             # <<<<<<<<<<<<<<
 *         def __set__(self, hbool_t val):
 *             self.cache_config.rpt_fcn_enabled = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_hbool_t(__pyx_v_self->cache_config.rpt_fcn_enabled); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.rpt_fcn_enabled.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  hbool_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_from_py_hbool_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (hbool_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 36; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.rpt_fcn_enabled.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((hbool_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":36
 *         def __get__(self):
 *             return self.cache_config.rpt_fcn_enabled
 *         def __set__(self, hbool_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.rpt_fcn_enabled = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":37
 *             return self.cache_config.rpt_fcn_enabled
 *         def __set__(self, hbool_t val):
 *             self.cache_config.rpt_fcn_enabled = val             # <<<<<<<<<<<<<<
 * 
 *     property evictions_enabled:
 */
  __pyx_v_self->cache_config.rpt_fcn_enabled = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_17evictions_enabled_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_17evictions_enabled_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_17evictions_enabled___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":40
 * 
 *     property evictions_enabled:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.evictions_enabled
 *         def __set__(self, hbool_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_17evictions_enabled___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":41
 *     property evictions_enabled:
 *         def __get__(self):
 *             return self.cache_config.evictions_enabled             # <<<<<<<<<<<<<<
 *         def __set__(self, hbool_t val):
 *             self.cache_config.evictions_enabled = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_hbool_t(__pyx_v_self->cache_config.evictions_enabled); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.evictions_enabled.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_17evictions_enabled_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_17evictions_enabled_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  hbool_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_from_py_hbool_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (hbool_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 42; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.evictions_enabled.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_17evictions_enabled_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((hbool_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":42
 *         def __get__(self):
 *             return self.cache_config.evictions_enabled
 *         def __set__(self, hbool_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.evictions_enabled = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_17evictions_enabled_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":43
 *             return self.cache_config.evictions_enabled
 *         def __set__(self, hbool_t val):
 *             self.cache_config.evictions_enabled = val             # <<<<<<<<<<<<<<
 * 
 *     property set_initial_size:
 */
  __pyx_v_self->cache_config.evictions_enabled = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_16set_initial_size_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_16set_initial_size_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_16set_initial_size___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":46
 * 
 *     property set_initial_size:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.set_initial_size
 *         def __set__(self, hbool_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_16set_initial_size___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":47
 *     property set_initial_size:
 *         def __get__(self):
 *             return self.cache_config.set_initial_size             # <<<<<<<<<<<<<<
 *         def __set__(self, hbool_t val):
 *             self.cache_config.set_initial_size = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_hbool_t(__pyx_v_self->cache_config.set_initial_size); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 47; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.set_initial_size.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_16set_initial_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_16set_initial_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  hbool_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_from_py_hbool_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (hbool_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 48; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.set_initial_size.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_16set_initial_size_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((hbool_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":48
 *         def __get__(self):
 *             return self.cache_config.set_initial_size
 *         def __set__(self, hbool_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.set_initial_size = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_16set_initial_size_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":49
 *             return self.cache_config.set_initial_size
 *         def __set__(self, hbool_t val):
 *             self.cache_config.set_initial_size = val             # <<<<<<<<<<<<<<
 * 
 *     property initial_size:
 */
  __pyx_v_self->cache_config.set_initial_size = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_12initial_size_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_12initial_size_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_12initial_size___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":52
 * 
 *     property initial_size:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.initial_size
 *         def __set__(self, size_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_12initial_size___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":53
 *     property initial_size:
 *         def __get__(self):
 *             return self.cache_config.initial_size             # <<<<<<<<<<<<<<
 *         def __set__(self, size_t val):
 *             self.cache_config.initial_size = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->cache_config.initial_size); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 53; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.initial_size.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_12initial_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_12initial_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  size_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_AsSize_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (size_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 54; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.initial_size.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_12initial_size_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((size_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":54
 *         def __get__(self):
 *             return self.cache_config.initial_size
 *         def __set__(self, size_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.initial_size = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_12initial_size_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":55
 *             return self.cache_config.initial_size
 *         def __set__(self, size_t val):
 *             self.cache_config.initial_size = val             # <<<<<<<<<<<<<<
 * 
 *     property min_clean_fraction:
 */
  __pyx_v_self->cache_config.initial_size = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_18min_clean_fraction_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_18min_clean_fraction_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_18min_clean_fraction___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":58
 * 
 *     property min_clean_fraction:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.min_clean_fraction
 *         def __set__(self, double val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_18min_clean_fraction___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":59
 *     property min_clean_fraction:
 *         def __get__(self):
 *             return self.cache_config.min_clean_fraction             # <<<<<<<<<<<<<<
 *         def __set__(self, double val):
 *             self.cache_config.min_clean_fraction = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->cache_config.min_clean_fraction); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 59; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.min_clean_fraction.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_18min_clean_fraction_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_18min_clean_fraction_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  double __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __pyx_PyFloat_AsDouble(__pyx_arg_val); if (unlikely((__pyx_v_val == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 60; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.min_clean_fraction.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_18min_clean_fraction_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((double)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":60
 *         def __get__(self):
 *             return self.cache_config.min_clean_fraction
 *         def __set__(self, double val):             # <<<<<<<<<<<<<<
 *             self.cache_config.min_clean_fraction = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_18min_clean_fraction_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":61
 *             return self.cache_config.min_clean_fraction
 *         def __set__(self, double val):
 *             self.cache_config.min_clean_fraction = val             # <<<<<<<<<<<<<<
 * 
 *     property max_size:
 */
  __pyx_v_self->cache_config.min_clean_fraction = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_8max_size_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_8max_size_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_8max_size___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":64
 * 
 *     property max_size:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.max_size
 *         def __set__(self, size_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_8max_size___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":65
 *     property max_size:
 *         def __get__(self):
 *             return self.cache_config.max_size             # <<<<<<<<<<<<<<
 *         def __set__(self, size_t val):
 *             self.cache_config.max_size = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->cache_config.max_size); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.max_size.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_8max_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_8max_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  size_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_AsSize_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (size_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.max_size.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_8max_size_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((size_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":66
 *         def __get__(self):
 *             return self.cache_config.max_size
 *         def __set__(self, size_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.max_size = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_8max_size_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":67
 *             return self.cache_config.max_size
 *         def __set__(self, size_t val):
 *             self.cache_config.max_size = val             # <<<<<<<<<<<<<<
 * 
 *     property min_size:
 */
  __pyx_v_self->cache_config.max_size = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_8min_size_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_8min_size_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_8min_size___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":70
 * 
 *     property min_size:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.min_size
 *         def __set__(self, size_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_8min_size___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":71
 *     property min_size:
 *         def __get__(self):
 *             return self.cache_config.min_size             # <<<<<<<<<<<<<<
 *         def __set__(self, size_t val):
 *             self.cache_config.min_size = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->cache_config.min_size); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.min_size.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_8min_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_8min_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  size_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_AsSize_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (size_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 72; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.min_size.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_8min_size_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((size_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":72
 *         def __get__(self):
 *             return self.cache_config.min_size
 *         def __set__(self, size_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.min_size = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_8min_size_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":73
 *             return self.cache_config.min_size
 *         def __set__(self, size_t val):
 *             self.cache_config.min_size = val             # <<<<<<<<<<<<<<
 * 
 *     property epoch_length:
 */
  __pyx_v_self->cache_config.min_size = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_12epoch_length_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_12epoch_length_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_12epoch_length___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":76
 * 
 *     property epoch_length:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.epoch_length
 *         def __set__(self, long int val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_12epoch_length___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":77
 *     property epoch_length:
 *         def __get__(self):
 *             return self.cache_config.epoch_length             # <<<<<<<<<<<<<<
 *         def __set__(self, long int val):
 *             self.cache_config.epoch_length = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->cache_config.epoch_length); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.epoch_length.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_12epoch_length_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_12epoch_length_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  long __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_AsLong(__pyx_arg_val); if (unlikely((__pyx_v_val == (long)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.epoch_length.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_12epoch_length_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((long)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":78
 *         def __get__(self):
 *             return self.cache_config.epoch_length
 *         def __set__(self, long int val):             # <<<<<<<<<<<<<<
 *             self.cache_config.epoch_length = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_12epoch_length_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, long __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":79
 *             return self.cache_config.epoch_length
 *         def __set__(self, long int val):
 *             self.cache_config.epoch_length = val             # <<<<<<<<<<<<<<
 * 
 *     #    /[inserted by cython to avoid comment start]* size increase control fields: *[inserted by cython to avoid comment closer]/
 */
  __pyx_v_self->cache_config.epoch_length = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_9incr_mode_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_9incr_mode_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_9incr_mode___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":83
 *     #    /[inserted by cython to avoid comment start]* size increase control fields: *[inserted by cython to avoid comment closer]/
 *     property incr_mode:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.incr_mode
 *         def __set__(self, H5C_cache_incr_mode val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_9incr_mode___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":84
 *     property incr_mode:
 *         def __get__(self):
 *             return self.cache_config.incr_mode             # <<<<<<<<<<<<<<
 *         def __set__(self, H5C_cache_incr_mode val):
 *             self.cache_config.incr_mode = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->cache_config.incr_mode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.incr_mode.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_9incr_mode_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_9incr_mode_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  enum H5C_cache_incr_mode __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = ((enum H5C_cache_incr_mode)PyInt_AsLong(__pyx_arg_val)); if (unlikely(PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.incr_mode.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_9incr_mode_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((enum H5C_cache_incr_mode)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":85
 *         def __get__(self):
 *             return self.cache_config.incr_mode
 *         def __set__(self, H5C_cache_incr_mode val):             # <<<<<<<<<<<<<<
 *             self.cache_config.incr_mode = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_9incr_mode_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, enum H5C_cache_incr_mode __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":86
 *             return self.cache_config.incr_mode
 *         def __set__(self, H5C_cache_incr_mode val):
 *             self.cache_config.incr_mode = val             # <<<<<<<<<<<<<<
 * 
 *     property lower_hr_threshold:
 */
  __pyx_v_self->cache_config.incr_mode = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":89
 * 
 *     property lower_hr_threshold:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.lower_hr_threshold
 *         def __set__(self, double val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":90
 *     property lower_hr_threshold:
 *         def __get__(self):
 *             return self.cache_config.lower_hr_threshold             # <<<<<<<<<<<<<<
 *         def __set__(self, double val):
 *             self.cache_config.lower_hr_threshold = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->cache_config.lower_hr_threshold); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 90; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.lower_hr_threshold.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  double __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __pyx_PyFloat_AsDouble(__pyx_arg_val); if (unlikely((__pyx_v_val == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 91; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.lower_hr_threshold.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((double)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":91
 *         def __get__(self):
 *             return self.cache_config.lower_hr_threshold
 *         def __set__(self, double val):             # <<<<<<<<<<<<<<
 *             self.cache_config.lower_hr_threshold = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":92
 *             return self.cache_config.lower_hr_threshold
 *         def __set__(self, double val):
 *             self.cache_config.lower_hr_threshold = val             # <<<<<<<<<<<<<<
 * 
 *     property increment:
 */
  __pyx_v_self->cache_config.lower_hr_threshold = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_9increment_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_9increment_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_9increment___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":95
 * 
 *     property increment:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.increment
 *         def __set__(self, double val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_9increment___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":96
 *     property increment:
 *         def __get__(self):
 *             return self.cache_config.increment             # <<<<<<<<<<<<<<
 *         def __set__(self, double val):
 *             self.cache_config.increment = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->cache_config.increment); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.increment.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_9increment_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_9increment_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  double __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __pyx_PyFloat_AsDouble(__pyx_arg_val); if (unlikely((__pyx_v_val == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.increment.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_9increment_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((double)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":97
 *         def __get__(self):
 *             return self.cache_config.increment
 *         def __set__(self, double val):             # <<<<<<<<<<<<<<
 *             self.cache_config.increment = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_9increment_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":98
 *             return self.cache_config.increment
 *         def __set__(self, double val):
 *             self.cache_config.increment = val             # <<<<<<<<<<<<<<
 * 
 *     property apply_max_increment:
 */
  __pyx_v_self->cache_config.increment = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_increment_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_increment_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_increment___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":101
 * 
 *     property apply_max_increment:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.apply_max_increment
 *         def __set__(self, hbool_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_increment___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":102
 *     property apply_max_increment:
 *         def __get__(self):
 *             return self.cache_config.apply_max_increment             # <<<<<<<<<<<<<<
 *         def __set__(self, hbool_t val):
 *             self.cache_config.apply_max_increment = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_hbool_t(__pyx_v_self->cache_config.apply_max_increment); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.apply_max_increment.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_increment_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_increment_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  hbool_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_from_py_hbool_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (hbool_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.apply_max_increment.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_increment_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((hbool_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":103
 *         def __get__(self):
 *             return self.cache_config.apply_max_increment
 *         def __set__(self, hbool_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.apply_max_increment = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_increment_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":104
 *             return self.cache_config.apply_max_increment
 *         def __set__(self, hbool_t val):
 *             self.cache_config.apply_max_increment = val             # <<<<<<<<<<<<<<
 * 
 *     property max_increment:
 */
  __pyx_v_self->cache_config.apply_max_increment = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_13max_increment_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_13max_increment_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_13max_increment___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":107
 * 
 *     property max_increment:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.max_increment
 *         def __set__(self, size_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_13max_increment___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":108
 *     property max_increment:
 *         def __get__(self):
 *             return self.cache_config.max_increment             # <<<<<<<<<<<<<<
 *         def __set__(self, size_t val):
 *             self.cache_config.max_increment = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->cache_config.max_increment); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.max_increment.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_13max_increment_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_13max_increment_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  size_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_AsSize_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (size_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.max_increment.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_13max_increment_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((size_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":109
 *         def __get__(self):
 *             return self.cache_config.max_increment
 *         def __set__(self, size_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.max_increment = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_13max_increment_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":110
 *             return self.cache_config.max_increment
 *         def __set__(self, size_t val):
 *             self.cache_config.max_increment = val             # <<<<<<<<<<<<<<
 * 
 *     property flash_incr_mode:
 */
  __pyx_v_self->cache_config.max_increment = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_incr_mode_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_incr_mode_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_incr_mode___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":113
 * 
 *     property flash_incr_mode:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.flash_incr_mode
 *         def __set__(self, H5C_cache_flash_incr_mode val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_incr_mode___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":114
 *     property flash_incr_mode:
 *         def __get__(self):
 *             return self.cache_config.flash_incr_mode             # <<<<<<<<<<<<<<
 *         def __set__(self, H5C_cache_flash_incr_mode val):
 *             self.cache_config.flash_incr_mode = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->cache_config.flash_incr_mode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.flash_incr_mode.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_incr_mode_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_incr_mode_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  enum H5C_cache_flash_incr_mode __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = ((enum H5C_cache_flash_incr_mode)PyInt_AsLong(__pyx_arg_val)); if (unlikely(PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.flash_incr_mode.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_incr_mode_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((enum H5C_cache_flash_incr_mode)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":115
 *         def __get__(self):
 *             return self.cache_config.flash_incr_mode
 *         def __set__(self, H5C_cache_flash_incr_mode val):             # <<<<<<<<<<<<<<
 *             self.cache_config.flash_incr_mode = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_incr_mode_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, enum H5C_cache_flash_incr_mode __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":116
 *             return self.cache_config.flash_incr_mode
 *         def __set__(self, H5C_cache_flash_incr_mode val):
 *             self.cache_config.flash_incr_mode = val             # <<<<<<<<<<<<<<
 * 
 *     property flash_multiple:
 */
  __pyx_v_self->cache_config.flash_incr_mode = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_14flash_multiple_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_14flash_multiple_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_14flash_multiple___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":119
 * 
 *     property flash_multiple:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.flash_multiple
 *         def __set__(self, double val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_14flash_multiple___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":120
 *     property flash_multiple:
 *         def __get__(self):
 *             return self.cache_config.flash_multiple             # <<<<<<<<<<<<<<
 *         def __set__(self, double val):
 *             self.cache_config.flash_multiple = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->cache_config.flash_multiple); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.flash_multiple.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_14flash_multiple_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_14flash_multiple_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  double __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __pyx_PyFloat_AsDouble(__pyx_arg_val); if (unlikely((__pyx_v_val == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.flash_multiple.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_14flash_multiple_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((double)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":121
 *         def __get__(self):
 *             return self.cache_config.flash_multiple
 *         def __set__(self, double val):             # <<<<<<<<<<<<<<
 *             self.cache_config.flash_multiple = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_14flash_multiple_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":122
 *             return self.cache_config.flash_multiple
 *         def __set__(self, double val):
 *             self.cache_config.flash_multiple = val             # <<<<<<<<<<<<<<
 * 
 *     property flash_threshold:
 */
  __pyx_v_self->cache_config.flash_multiple = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_threshold_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_threshold_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_threshold___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":125
 * 
 *     property flash_threshold:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.flash_threshold
 *         def __set__(self, double val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_threshold___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":126
 *     property flash_threshold:
 *         def __get__(self):
 *             return self.cache_config.flash_threshold             # <<<<<<<<<<<<<<
 *         def __set__(self, double val):
 *             self.cache_config.flash_threshold = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->cache_config.flash_threshold); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.flash_threshold.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  double __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __pyx_PyFloat_AsDouble(__pyx_arg_val); if (unlikely((__pyx_v_val == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.flash_threshold.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_threshold_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((double)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":127
 *         def __get__(self):
 *             return self.cache_config.flash_threshold
 *         def __set__(self, double val):             # <<<<<<<<<<<<<<
 *             self.cache_config.flash_threshold = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_15flash_threshold_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":128
 *             return self.cache_config.flash_threshold
 *         def __set__(self, double val):
 *             self.cache_config.flash_threshold = val             # <<<<<<<<<<<<<<
 * 
 *     # /[inserted by cython to avoid comment start]* size decrease control fields: *[inserted by cython to avoid comment closer]/
 */
  __pyx_v_self->cache_config.flash_threshold = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_9decr_mode_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_9decr_mode_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_9decr_mode___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":132
 *     # /[inserted by cython to avoid comment start]* size decrease control fields: *[inserted by cython to avoid comment closer]/
 *     property decr_mode:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.decr_mode
 *         def __set__(self, H5C_cache_decr_mode val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_9decr_mode___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":133
 *     property decr_mode:
 *         def __get__(self):
 *             return self.cache_config.decr_mode             # <<<<<<<<<<<<<<
 *         def __set__(self, H5C_cache_decr_mode val):
 *             self.cache_config.decr_mode = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->cache_config.decr_mode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.decr_mode.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_9decr_mode_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_9decr_mode_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  enum H5C_cache_decr_mode __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = ((enum H5C_cache_decr_mode)PyInt_AsLong(__pyx_arg_val)); if (unlikely(PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 134; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.decr_mode.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_9decr_mode_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((enum H5C_cache_decr_mode)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":134
 *         def __get__(self):
 *             return self.cache_config.decr_mode
 *         def __set__(self, H5C_cache_decr_mode val):             # <<<<<<<<<<<<<<
 *             self.cache_config.decr_mode = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_9decr_mode_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, enum H5C_cache_decr_mode __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":135
 *             return self.cache_config.decr_mode
 *         def __set__(self, H5C_cache_decr_mode val):
 *             self.cache_config.decr_mode = val             # <<<<<<<<<<<<<<
 * 
 *     property upper_hr_threshold:
 */
  __pyx_v_self->cache_config.decr_mode = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":138
 * 
 *     property upper_hr_threshold:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.upper_hr_threshold
 *         def __set__(self, double val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":139
 *     property upper_hr_threshold:
 *         def __get__(self):
 *             return self.cache_config.upper_hr_threshold             # <<<<<<<<<<<<<<
 *         def __set__(self, double val):
 *             self.cache_config.upper_hr_threshold = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->cache_config.upper_hr_threshold); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.upper_hr_threshold.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  double __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __pyx_PyFloat_AsDouble(__pyx_arg_val); if (unlikely((__pyx_v_val == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.upper_hr_threshold.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((double)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":140
 *         def __get__(self):
 *             return self.cache_config.upper_hr_threshold
 *         def __set__(self, double val):             # <<<<<<<<<<<<<<
 *             self.cache_config.upper_hr_threshold = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":141
 *             return self.cache_config.upper_hr_threshold
 *         def __set__(self, double val):
 *             self.cache_config.upper_hr_threshold = val             # <<<<<<<<<<<<<<
 * 
 *     property decrement:
 */
  __pyx_v_self->cache_config.upper_hr_threshold = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_9decrement_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_9decrement_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_9decrement___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":144
 * 
 *     property decrement:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.decrement
 *         def __set__(self, double val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_9decrement___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":145
 *     property decrement:
 *         def __get__(self):
 *             return self.cache_config.decrement             # <<<<<<<<<<<<<<
 *         def __set__(self, double val):
 *             self.cache_config.decrement = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->cache_config.decrement); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 145; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.decrement.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_9decrement_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_9decrement_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  double __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __pyx_PyFloat_AsDouble(__pyx_arg_val); if (unlikely((__pyx_v_val == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 146; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.decrement.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_9decrement_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((double)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":146
 *         def __get__(self):
 *             return self.cache_config.decrement
 *         def __set__(self, double val):             # <<<<<<<<<<<<<<
 *             self.cache_config.decrement = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_9decrement_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":147
 *             return self.cache_config.decrement
 *         def __set__(self, double val):
 *             self.cache_config.decrement = val             # <<<<<<<<<<<<<<
 * 
 *     property apply_max_decrement:
 */
  __pyx_v_self->cache_config.decrement = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_decrement_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_decrement_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_decrement___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":150
 * 
 *     property apply_max_decrement:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.apply_max_decrement
 *         def __set__(self, hbool_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_decrement___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":151
 *     property apply_max_decrement:
 *         def __get__(self):
 *             return self.cache_config.apply_max_decrement             # <<<<<<<<<<<<<<
 *         def __set__(self, hbool_t val):
 *             self.cache_config.apply_max_decrement = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_hbool_t(__pyx_v_self->cache_config.apply_max_decrement); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 151; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.apply_max_decrement.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_decrement_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_decrement_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  hbool_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_from_py_hbool_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (hbool_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 152; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.apply_max_decrement.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_decrement_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((hbool_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":152
 *         def __get__(self):
 *             return self.cache_config.apply_max_decrement
 *         def __set__(self, hbool_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.apply_max_decrement = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_max_decrement_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":153
 *             return self.cache_config.apply_max_decrement
 *         def __set__(self, hbool_t val):
 *             self.cache_config.apply_max_decrement = val             # <<<<<<<<<<<<<<
 * 
 *     property max_decrement:
 */
  __pyx_v_self->cache_config.apply_max_decrement = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_13max_decrement_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_13max_decrement_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_13max_decrement___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":156
 * 
 *     property max_decrement:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.max_decrement
 *         def __set__(self, size_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_13max_decrement___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":157
 *     property max_decrement:
 *         def __get__(self):
 *             return self.cache_config.max_decrement             # <<<<<<<<<<<<<<
 *         def __set__(self, size_t val):
 *             self.cache_config.max_decrement = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->cache_config.max_decrement); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 157; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.max_decrement.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_13max_decrement_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_13max_decrement_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  size_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_AsSize_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (size_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.max_decrement.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_13max_decrement_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((size_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":158
 *         def __get__(self):
 *             return self.cache_config.max_decrement
 *         def __set__(self, size_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.max_decrement = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_13max_decrement_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, size_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":159
 *             return self.cache_config.max_decrement
 *         def __set__(self, size_t val):
 *             self.cache_config.max_decrement = val             # <<<<<<<<<<<<<<
 * 
 *     property epochs_before_eviction:
 */
  __pyx_v_self->cache_config.max_decrement = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":162
 * 
 *     property epochs_before_eviction:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.epochs_before_eviction
 *         def __set__(self, int val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":163
 *     property epochs_before_eviction:
 *         def __get__(self):
 *             return self.cache_config.epochs_before_eviction             # <<<<<<<<<<<<<<
 *         def __set__(self, int val):
 *             self.cache_config.epochs_before_eviction = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->cache_config.epochs_before_eviction); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.epochs_before_eviction.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  int __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_AsInt(__pyx_arg_val); if (unlikely((__pyx_v_val == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 164; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.epochs_before_eviction.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((int)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":164
 *         def __get__(self):
 *             return self.cache_config.epochs_before_eviction
 *         def __set__(self, int val):             # <<<<<<<<<<<<<<
 *             self.cache_config.epochs_before_eviction = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, int __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":165
 *             return self.cache_config.epochs_before_eviction
 *         def __set__(self, int val):
 *             self.cache_config.epochs_before_eviction = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->cache_config.epochs_before_eviction = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":170
 * 
 *     property apply_empty_reserve:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.apply_empty_reserve
 *         def __set__(self, hbool_t val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":171
 *     property apply_empty_reserve:
 *         def __get__(self):
 *             return self.cache_config.apply_empty_reserve             # <<<<<<<<<<<<<<
 *         def __set__(self, hbool_t val):
 *             self.cache_config.apply_empty_reserve = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_hbool_t(__pyx_v_self->cache_config.apply_empty_reserve); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 171; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.apply_empty_reserve.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  hbool_t __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_from_py_hbool_t(__pyx_arg_val); if (unlikely((__pyx_v_val == (hbool_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.apply_empty_reserve.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((hbool_t)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":172
 *         def __get__(self):
 *             return self.cache_config.apply_empty_reserve
 *         def __set__(self, hbool_t val):             # <<<<<<<<<<<<<<
 *             self.cache_config.apply_empty_reserve = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, hbool_t __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":173
 *             return self.cache_config.apply_empty_reserve
 *         def __set__(self, hbool_t val):
 *             self.cache_config.apply_empty_reserve = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->cache_config.apply_empty_reserve = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_13empty_reserve_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_13empty_reserve_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_13empty_reserve___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":177
 * 
 *     property empty_reserve:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.empty_reserve
 *         def __set__(self, double val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_13empty_reserve___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":178
 *     property empty_reserve:
 *         def __get__(self):
 *             return self.cache_config.empty_reserve             # <<<<<<<<<<<<<<
 *         def __set__(self, double val):
 *             self.cache_config.empty_reserve = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->cache_config.empty_reserve); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.empty_reserve.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_13empty_reserve_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_13empty_reserve_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  double __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __pyx_PyFloat_AsDouble(__pyx_arg_val); if (unlikely((__pyx_v_val == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.empty_reserve.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_13empty_reserve_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((double)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":179
 *         def __get__(self):
 *             return self.cache_config.empty_reserve
 *         def __set__(self, double val):             # <<<<<<<<<<<<<<
 *             self.cache_config.empty_reserve = val
 * 
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_13empty_reserve_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, double __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":180
 *             return self.cache_config.empty_reserve
 *         def __set__(self, double val):
 *             self.cache_config.empty_reserve = val             # <<<<<<<<<<<<<<
 * 
 *     # /[inserted by cython to avoid comment start]* parallel configuration fields: *[inserted by cython to avoid comment closer]/
 */
  __pyx_v_self->cache_config.empty_reserve = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold___get__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":184
 *     # /[inserted by cython to avoid comment start]* parallel configuration fields: *[inserted by cython to avoid comment closer]/
 *     property dirty_bytes_threshold:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.cache_config.dirty_bytes_threshold
 *         def __set__(self, int val):
 */

static PyObject *__pyx_pf_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold___get__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "h5py/h5ac.pyx":185
 *     property dirty_bytes_threshold:
 *         def __get__(self):
 *             return self.cache_config.dirty_bytes_threshold             # <<<<<<<<<<<<<<
 *         def __set__(self, int val):
 *             self.cache_config.dirty_bytes_threshold = val
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromLong(__pyx_v_self->cache_config.dirty_bytes_threshold); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.dirty_bytes_threshold.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val); /*proto*/
static int __pyx_pw_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_val) {
  int __pyx_v_val;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_val); {
    __pyx_v_val = __Pyx_PyInt_AsInt(__pyx_arg_val); if (unlikely((__pyx_v_val == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 186; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("h5py.h5ac.CacheConfig.dirty_bytes_threshold.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold_2__set__(((struct __pyx_obj_4h5py_4h5ac_CacheConfig *)__pyx_v_self), ((int)__pyx_v_val));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "h5py/h5ac.pyx":186
 *         def __get__(self):
 *             return self.cache_config.dirty_bytes_threshold
 *         def __set__(self, int val):             # <<<<<<<<<<<<<<
 *             self.cache_config.dirty_bytes_threshold = val
 */

static int __pyx_pf_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold_2__set__(struct __pyx_obj_4h5py_4h5ac_CacheConfig *__pyx_v_self, int __pyx_v_val) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "h5py/h5ac.pyx":187
 *             return self.cache_config.dirty_bytes_threshold
 *         def __set__(self, int val):
 *             self.cache_config.dirty_bytes_threshold = val             # <<<<<<<<<<<<<<
 */
  __pyx_v_self->cache_config.dirty_bytes_threshold = __pyx_v_val;

  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_4h5py_4h5ac_CacheConfig(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  if (__pyx_pw_4h5py_4h5ac_11CacheConfig_1__cinit__(o, __pyx_empty_tuple, NULL) < 0) {
    Py_DECREF(o); o = 0;
  }
  return o;
}

static void __pyx_tp_dealloc_4h5py_4h5ac_CacheConfig(PyObject *o) {
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_version(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_7version_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_version(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_7version_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_rpt_fcn_enabled(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_rpt_fcn_enabled(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_15rpt_fcn_enabled_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_evictions_enabled(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_17evictions_enabled_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_evictions_enabled(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_17evictions_enabled_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_set_initial_size(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_16set_initial_size_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_set_initial_size(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_16set_initial_size_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_initial_size(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_12initial_size_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_initial_size(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_12initial_size_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_min_clean_fraction(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_18min_clean_fraction_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_min_clean_fraction(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_18min_clean_fraction_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_max_size(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_8max_size_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_max_size(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_8max_size_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_min_size(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_8min_size_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_min_size(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_8min_size_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_epoch_length(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_12epoch_length_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_epoch_length(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_12epoch_length_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_incr_mode(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_9incr_mode_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_incr_mode(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_9incr_mode_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_lower_hr_threshold(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_lower_hr_threshold(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_18lower_hr_threshold_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_increment(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_9increment_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_increment(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_9increment_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_apply_max_increment(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_increment_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_apply_max_increment(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_increment_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_max_increment(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_13max_increment_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_max_increment(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_13max_increment_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_flash_incr_mode(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_incr_mode_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_flash_incr_mode(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_incr_mode_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_flash_multiple(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_14flash_multiple_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_flash_multiple(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_14flash_multiple_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_flash_threshold(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_threshold_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_flash_threshold(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_15flash_threshold_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_decr_mode(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_9decr_mode_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_decr_mode(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_9decr_mode_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_upper_hr_threshold(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_upper_hr_threshold(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_18upper_hr_threshold_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_decrement(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_9decrement_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_decrement(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_9decrement_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_apply_max_decrement(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_decrement_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_apply_max_decrement(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_max_decrement_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_max_decrement(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_13max_decrement_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_max_decrement(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_13max_decrement_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_epochs_before_eviction(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_epochs_before_eviction(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_22epochs_before_eviction_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_apply_empty_reserve(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_apply_empty_reserve(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_19apply_empty_reserve_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_empty_reserve(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_13empty_reserve_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_empty_reserve(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_13empty_reserve_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_4h5py_4h5ac_11CacheConfig_dirty_bytes_threshold(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold_1__get__(o);
}

static int __pyx_setprop_4h5py_4h5ac_11CacheConfig_dirty_bytes_threshold(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_4h5py_4h5ac_11CacheConfig_21dirty_bytes_threshold_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_4h5py_4h5ac_CacheConfig[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4h5py_4h5ac_CacheConfig[] = {
  {(char *)"version", __pyx_getprop_4h5py_4h5ac_11CacheConfig_version, __pyx_setprop_4h5py_4h5ac_11CacheConfig_version, 0, 0},
  {(char *)"rpt_fcn_enabled", __pyx_getprop_4h5py_4h5ac_11CacheConfig_rpt_fcn_enabled, __pyx_setprop_4h5py_4h5ac_11CacheConfig_rpt_fcn_enabled, 0, 0},
  {(char *)"evictions_enabled", __pyx_getprop_4h5py_4h5ac_11CacheConfig_evictions_enabled, __pyx_setprop_4h5py_4h5ac_11CacheConfig_evictions_enabled, 0, 0},
  {(char *)"set_initial_size", __pyx_getprop_4h5py_4h5ac_11CacheConfig_set_initial_size, __pyx_setprop_4h5py_4h5ac_11CacheConfig_set_initial_size, 0, 0},
  {(char *)"initial_size", __pyx_getprop_4h5py_4h5ac_11CacheConfig_initial_size, __pyx_setprop_4h5py_4h5ac_11CacheConfig_initial_size, 0, 0},
  {(char *)"min_clean_fraction", __pyx_getprop_4h5py_4h5ac_11CacheConfig_min_clean_fraction, __pyx_setprop_4h5py_4h5ac_11CacheConfig_min_clean_fraction, 0, 0},
  {(char *)"max_size", __pyx_getprop_4h5py_4h5ac_11CacheConfig_max_size, __pyx_setprop_4h5py_4h5ac_11CacheConfig_max_size, 0, 0},
  {(char *)"min_size", __pyx_getprop_4h5py_4h5ac_11CacheConfig_min_size, __pyx_setprop_4h5py_4h5ac_11CacheConfig_min_size, 0, 0},
  {(char *)"epoch_length", __pyx_getprop_4h5py_4h5ac_11CacheConfig_epoch_length, __pyx_setprop_4h5py_4h5ac_11CacheConfig_epoch_length, 0, 0},
  {(char *)"incr_mode", __pyx_getprop_4h5py_4h5ac_11CacheConfig_incr_mode, __pyx_setprop_4h5py_4h5ac_11CacheConfig_incr_mode, 0, 0},
  {(char *)"lower_hr_threshold", __pyx_getprop_4h5py_4h5ac_11CacheConfig_lower_hr_threshold, __pyx_setprop_4h5py_4h5ac_11CacheConfig_lower_hr_threshold, 0, 0},
  {(char *)"increment", __pyx_getprop_4h5py_4h5ac_11CacheConfig_increment, __pyx_setprop_4h5py_4h5ac_11CacheConfig_increment, 0, 0},
  {(char *)"apply_max_increment", __pyx_getprop_4h5py_4h5ac_11CacheConfig_apply_max_increment, __pyx_setprop_4h5py_4h5ac_11CacheConfig_apply_max_increment, 0, 0},
  {(char *)"max_increment", __pyx_getprop_4h5py_4h5ac_11CacheConfig_max_increment, __pyx_setprop_4h5py_4h5ac_11CacheConfig_max_increment, 0, 0},
  {(char *)"flash_incr_mode", __pyx_getprop_4h5py_4h5ac_11CacheConfig_flash_incr_mode, __pyx_setprop_4h5py_4h5ac_11CacheConfig_flash_incr_mode, 0, 0},
  {(char *)"flash_multiple", __pyx_getprop_4h5py_4h5ac_11CacheConfig_flash_multiple, __pyx_setprop_4h5py_4h5ac_11CacheConfig_flash_multiple, 0, 0},
  {(char *)"flash_threshold", __pyx_getprop_4h5py_4h5ac_11CacheConfig_flash_threshold, __pyx_setprop_4h5py_4h5ac_11CacheConfig_flash_threshold, 0, 0},
  {(char *)"decr_mode", __pyx_getprop_4h5py_4h5ac_11CacheConfig_decr_mode, __pyx_setprop_4h5py_4h5ac_11CacheConfig_decr_mode, 0, 0},
  {(char *)"upper_hr_threshold", __pyx_getprop_4h5py_4h5ac_11CacheConfig_upper_hr_threshold, __pyx_setprop_4h5py_4h5ac_11CacheConfig_upper_hr_threshold, 0, 0},
  {(char *)"decrement", __pyx_getprop_4h5py_4h5ac_11CacheConfig_decrement, __pyx_setprop_4h5py_4h5ac_11CacheConfig_decrement, 0, 0},
  {(char *)"apply_max_decrement", __pyx_getprop_4h5py_4h5ac_11CacheConfig_apply_max_decrement, __pyx_setprop_4h5py_4h5ac_11CacheConfig_apply_max_decrement, 0, 0},
  {(char *)"max_decrement", __pyx_getprop_4h5py_4h5ac_11CacheConfig_max_decrement, __pyx_setprop_4h5py_4h5ac_11CacheConfig_max_decrement, 0, 0},
  {(char *)"epochs_before_eviction", __pyx_getprop_4h5py_4h5ac_11CacheConfig_epochs_before_eviction, __pyx_setprop_4h5py_4h5ac_11CacheConfig_epochs_before_eviction, 0, 0},
  {(char *)"apply_empty_reserve", __pyx_getprop_4h5py_4h5ac_11CacheConfig_apply_empty_reserve, __pyx_setprop_4h5py_4h5ac_11CacheConfig_apply_empty_reserve, 0, 0},
  {(char *)"empty_reserve", __pyx_getprop_4h5py_4h5ac_11CacheConfig_empty_reserve, __pyx_setprop_4h5py_4h5ac_11CacheConfig_empty_reserve, 0, 0},
  {(char *)"dirty_bytes_threshold", __pyx_getprop_4h5py_4h5ac_11CacheConfig_dirty_bytes_threshold, __pyx_setprop_4h5py_4h5ac_11CacheConfig_dirty_bytes_threshold, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_CacheConfig = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_CacheConfig = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_CacheConfig = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_CacheConfig = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_4h5py_4h5ac_CacheConfig = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("h5py.h5ac.CacheConfig"), /*tp_name*/
  sizeof(struct __pyx_obj_4h5py_4h5ac_CacheConfig), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4h5py_4h5ac_CacheConfig, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_CacheConfig, /*tp_as_number*/
  &__pyx_tp_as_sequence_CacheConfig, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_CacheConfig, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_CacheConfig, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  __Pyx_DOCSTR("Represents H5AC_cache_config_t objects\n\n    "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4h5py_4h5ac_CacheConfig, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4h5py_4h5ac_CacheConfig, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4h5py_4h5ac_CacheConfig, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    __Pyx_NAMESTR("h5ac"),
    __Pyx_DOCSTR(__pyx_k_1), /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_n_s____main__, __pyx_k____main__, sizeof(__pyx_k____main__), 0, 0, 1, 1},
  {&__pyx_n_s____test__, __pyx_k____test__, sizeof(__pyx_k____test__), 0, 0, 1, 1},
  {&__pyx_n_s___objects, __pyx_k___objects, sizeof(__pyx_k___objects), 0, 0, 1, 1},
  {&__pyx_n_s__h5py, __pyx_k__h5py, sizeof(__pyx_k__h5py), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  return 0;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC inith5ac(void); /*proto*/
PyMODINIT_FUNC inith5ac(void)
#else
PyMODINIT_FUNC PyInit_h5ac(void); /*proto*/
PyMODINIT_FUNC PyInit_h5ac(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_h5ac(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("h5ac"), __pyx_methods, __Pyx_DOCSTR(__pyx_k_1), 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "h5py.h5ac")) {
      if (unlikely(PyDict_SetItemString(modules, "h5py.h5ac", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_module_is_main_h5py__h5ac) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s____main__) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_4h5py_4h5ac_CacheConfig) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 17; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "CacheConfig", (PyObject *)&__pyx_type_4h5py_4h5ac_CacheConfig) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 17; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_4h5py_4h5ac_CacheConfig = &__pyx_type_4h5py_4h5ac_CacheConfig;
  /*--- Type import code ---*/
  __pyx_ptype_4h5py_8_objects_ObjectID = __Pyx_ImportType("h5py._objects", "ObjectID", sizeof(struct __pyx_obj_4h5py_8_objects_ObjectID), 1); if (unlikely(!__pyx_ptype_4h5py_8_objects_ObjectID)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  __pyx_t_1 = __Pyx_ImportModule("h5py._objects"); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_ImportFunction(__pyx_t_1, "pdefault", (void (**)(void))&__pyx_f_4h5py_8_objects_pdefault, "hid_t (struct __pyx_obj_4h5py_8_objects_ObjectID *)") < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*--- Execution code ---*/

  /* "h5py/h5ac.pyx":15
 * """
 * from _objects cimport pdefault
 * from h5py import _objects             # <<<<<<<<<<<<<<
 * 
 * cdef class CacheConfig:
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s___objects));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s___objects));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s___objects));
  __pyx_t_3 = __Pyx_Import(((PyObject *)__pyx_n_s__h5py), ((PyObject *)__pyx_t_2), -1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s___objects);
  if (__pyx_t_2 == NULL) {
    if (PyErr_ExceptionMatches(PyExc_AttributeError)) __Pyx_RaiseImportError(__pyx_n_s___objects);
    if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_2);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s___objects, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "h5py/h5ac.pyx":1
 * # This file is part of h5py, a Python interface to the HDF5 library.             # <<<<<<<<<<<<<<
 * #
 * # http://www.h5py.org
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s____test__, ((PyObject *)__pyx_t_3)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  if (__pyx_m) {
    __Pyx_AddTraceback("init h5py.h5ac", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init h5py.h5ac");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%s() takes %s %" CYTHON_FORMAT_SSIZE_T "d positional argument%s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CPYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import = 0;
    py_import = __Pyx_GetAttrString(__pyx_b, "__import__");
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    #if PY_VERSION_HEX >= 0x02050000
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0; /* try absolute import on failure */
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
    #else
    if (level>0) {
        PyErr_SetString(PyExc_RuntimeError, "Relative import is not supported for Python <=2.4.");
        goto bad;
    }
    module = PyObject_CallFunctionObjArgs(py_import,
        name, global_dict, empty_dict, list, NULL);
    #endif
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

static CYTHON_INLINE void __Pyx_RaiseImportError(PyObject *name) {
#if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_ImportError, "cannot import name %.230s",
                 PyString_AsString(name));
#else
    PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
#endif
}

static CYTHON_INLINE hbool_t __Pyx_PyInt_from_py_hbool_t(PyObject* x) {
    const hbool_t neg_one = (hbool_t)-1, const_zero = (hbool_t)0;
    const int is_unsigned = const_zero < neg_one;
    if (sizeof(hbool_t) == sizeof(char)) {
        if (is_unsigned)
            return (hbool_t)__Pyx_PyInt_AsUnsignedChar(x);
        else
            return (hbool_t)__Pyx_PyInt_AsSignedChar(x);
    } else if (sizeof(hbool_t) == sizeof(short)) {
        if (is_unsigned)
            return (hbool_t)__Pyx_PyInt_AsUnsignedShort(x);
        else
            return (hbool_t)__Pyx_PyInt_AsSignedShort(x);
    } else if (sizeof(hbool_t) == sizeof(int)) {
        if (is_unsigned)
            return (hbool_t)__Pyx_PyInt_AsUnsignedInt(x);
        else
            return (hbool_t)__Pyx_PyInt_AsSignedInt(x);
    } else if (sizeof(hbool_t) == sizeof(long)) {
        if (is_unsigned)
            return (hbool_t)__Pyx_PyInt_AsUnsignedLong(x);
        else
            return (hbool_t)__Pyx_PyInt_AsSignedLong(x);
    } else if (sizeof(hbool_t) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return (hbool_t)__Pyx_PyInt_AsUnsignedLongLong(x);
        else
            return (hbool_t)__Pyx_PyInt_AsSignedLongLong(x);
    }  else {
        #if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
        #else
        hbool_t val;
        PyObject *v = __Pyx_PyNumber_Int(x);
        #if PY_VERSION_HEX < 0x03000000
        if (likely(v) && !PyLong_Check(v)) {
            PyObject *tmp = v;
            v = PyNumber_Long(tmp);
            Py_DECREF(tmp);
        }
        #endif
        if (likely(v)) {
            int one = 1; int is_little = (int)*(unsigned char *)&one;
            unsigned char *bytes = (unsigned char *)&val;
            int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                          bytes, sizeof(val),
                                          is_little, !is_unsigned);
            Py_DECREF(v);
            if (likely(!ret))
                return val;
        }
        #endif
        return (hbool_t)-1;
    }
}

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_hbool_t(hbool_t val) {
    const hbool_t neg_one = (hbool_t)-1, const_zero = (hbool_t)0;
    const int is_unsigned = const_zero < neg_one;
    if ((sizeof(hbool_t) == sizeof(char))  ||
        (sizeof(hbool_t) == sizeof(short))) {
        return PyInt_FromLong((long)val);
    } else if ((sizeof(hbool_t) == sizeof(int)) ||
               (sizeof(hbool_t) == sizeof(long))) {
        if (is_unsigned)
            return PyLong_FromUnsignedLong((unsigned long)val);
        else
            return PyInt_FromLong((long)val);
    } else if (sizeof(hbool_t) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG)val);
        else
            return PyLong_FromLongLong((PY_LONG_LONG)val);
    } else {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        return _PyLong_FromByteArray(bytes, sizeof(hbool_t),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_hid_t(hid_t val) {
    const hid_t neg_one = (hid_t)-1, const_zero = (hid_t)0;
    const int is_unsigned = const_zero < neg_one;
    if ((sizeof(hid_t) == sizeof(char))  ||
        (sizeof(hid_t) == sizeof(short))) {
        return PyInt_FromLong((long)val);
    } else if ((sizeof(hid_t) == sizeof(int)) ||
               (sizeof(hid_t) == sizeof(long))) {
        if (is_unsigned)
            return PyLong_FromUnsignedLong((unsigned long)val);
        else
            return PyInt_FromLong((long)val);
    } else if (sizeof(hid_t) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG)val);
        else
            return PyLong_FromLongLong((PY_LONG_LONG)val);
    } else {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        return _PyLong_FromByteArray(bytes, sizeof(hid_t),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject* x) {
    const unsigned char neg_one = (unsigned char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned char" :
                    "value too large to convert to unsigned char");
            }
            return (unsigned char)-1;
        }
        return (unsigned char)val;
    }
    return (unsigned char)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject* x) {
    const unsigned short neg_one = (unsigned short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned short" :
                    "value too large to convert to unsigned short");
            }
            return (unsigned short)-1;
        }
        return (unsigned short)val;
    }
    return (unsigned short)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject* x) {
    const unsigned int neg_one = (unsigned int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned int" :
                    "value too large to convert to unsigned int");
            }
            return (unsigned int)-1;
        }
        return (unsigned int)val;
    }
    return (unsigned int)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject* x) {
    const char neg_one = (char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to char" :
                    "value too large to convert to char");
            }
            return (char)-1;
        }
        return (char)val;
    }
    return (char)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject* x) {
    const short neg_one = (short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to short" :
                    "value too large to convert to short");
            }
            return (short)-1;
        }
        return (short)val;
    }
    return (short)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject* x) {
    const signed char neg_one = (signed char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed char" :
                    "value too large to convert to signed char");
            }
            return (signed char)-1;
        }
        return (signed char)val;
    }
    return (signed char)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject* x) {
    const signed short neg_one = (signed short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed short" :
                    "value too large to convert to signed short");
            }
            return (signed short)-1;
        }
        return (signed short)val;
    }
    return (signed short)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject* x) {
    const signed int neg_one = (signed int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed int" :
                    "value too large to convert to signed int");
            }
            return (signed int)-1;
        }
        return (signed int)val;
    }
    return (signed int)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject* x) {
    const unsigned long neg_one = (unsigned long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned long");
            return (unsigned long)-1;
        }
        return (unsigned long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned long");
                return (unsigned long)-1;
            }
            return (unsigned long)PyLong_AsUnsignedLong(x);
        } else {
            return (unsigned long)PyLong_AsLong(x);
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned long)-1;
        val = __Pyx_PyInt_AsUnsignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject* x) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned PY_LONG_LONG");
            return (unsigned PY_LONG_LONG)-1;
        }
        return (unsigned PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned PY_LONG_LONG");
                return (unsigned PY_LONG_LONG)-1;
            }
            return (unsigned PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (unsigned PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        unsigned PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsUnsignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject* x) {
    const long neg_one = (long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to long");
            return (long)-1;
        }
        return (long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long)-1;
            }
            return (long)PyLong_AsUnsignedLong(x);
        } else {
            return (long)PyLong_AsLong(x);
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long)-1;
        val = __Pyx_PyInt_AsLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject* x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to PY_LONG_LONG");
            return (PY_LONG_LONG)-1;
        }
        return (PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to PY_LONG_LONG");
                return (PY_LONG_LONG)-1;
            }
            return (PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject* x) {
    const signed long neg_one = (signed long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed long");
            return (signed long)-1;
        }
        return (signed long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed long");
                return (signed long)-1;
            }
            return (signed long)PyLong_AsUnsignedLong(x);
        } else {
            return (signed long)PyLong_AsLong(x);
        }
    } else {
        signed long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed long)-1;
        val = __Pyx_PyInt_AsSignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject* x) {
    const signed PY_LONG_LONG neg_one = (signed PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed PY_LONG_LONG");
            return (signed PY_LONG_LONG)-1;
        }
        return (signed PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed PY_LONG_LONG");
                return (signed PY_LONG_LONG)-1;
            }
            return (signed PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (signed PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        signed PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsSignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

#ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%s.%s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility",
            module_name, class_name);
        #if PY_VERSION_HEX < 0x02050000
        if (PyErr_Warn(NULL, warning) < 0) goto bad;
        #else
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
        #endif
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%s.%s has the wrong size, try recompiling",
            module_name, class_name);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

#ifndef __PYX_HAVE_RT_ImportFunction
#define __PYX_HAVE_RT_ImportFunction
static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, funcname);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%s does not export expected C function %s",
                PyModule_GetName(module), funcname);
        goto bad;
    }
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3 && PY_MINOR_VERSION==0)
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C function %s.%s has wrong signature (expected %s, got %s)",
             PyModule_GetName(module), funcname, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    tmp.p = PyCapsule_GetPointer(cobj, sig);
#else
    {const char *desc, *s1, *s2;
    desc = (const char *)PyCObject_GetDesc(cobj);
    if (!desc)
        goto bad;
    s1 = desc; s2 = sig;
    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
    if (*s1 != *s2) {
        PyErr_Format(PyExc_TypeError,
            "C function %s.%s has wrong signature (expected %s, got %s)",
             PyModule_GetName(module), funcname, sig, desc);
        goto bad;
    }
    tmp.p = PyCObject_AsVoidPtr(cobj);}
#endif
    *f = tmp.fp;
    if (!(*f))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_VERSION_HEX < 0x03000000
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_VERSION_HEX < 0x03000000
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%s__ returned non-%s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject* x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject* x) {
   unsigned PY_LONG_LONG val = __Pyx_PyInt_AsUnsignedLongLong(x);
   if (unlikely(val == (unsigned PY_LONG_LONG)-1 && PyErr_Occurred())) {
       return (size_t)-1;
   } else if (unlikely(val != (unsigned PY_LONG_LONG)(size_t)val)) {
       PyErr_SetString(PyExc_OverflowError,
                       "value too large to convert to size_t");
       return (size_t)-1;
   }
   return (size_t)val;
}


#endif /* Py_PYTHON_H */
